@@ -4,5 +4,8 @@ from .metrics.collector import MetricCollector
 from .metrics.metrics import PrometheusMiddleware
 from .metrics import config
 
+from .loggers.logger import logger
+from .loggers.accesslog import _create_logger, AccessLogAtoms
+
 from .utils.singleton import SingletonMeta
 from .utils.gunicorn_multiprocess import clear_multiproc_dir
