@@ -71,7 +71,7 @@ class AccessLogAtoms(dict):
             {
                 "h": remote_addr,
                 "l": "-",
-                "t": time.strftime("'%Y-%m-%dT%H:%M:%SZ'"),
+                "t": time.strftime("%Y-%m-%dT%H:%M:%SZ"),
                 "r": f"{method} {request['path']} {protocol}",
                 "R": f"{method} {path_with_qs} {protocol}",
                 "s": response["status"],
@@ -87,7 +87,7 @@ class AccessLogAtoms(dict):
                 "f": self["{Referer}i"],
                 "a": self["{User-Agent}i"],
                 "T": int(request_time),
-                "M": int(request_time * 1000) ,
+                "M": int(request_time * 1000),
                 "D": int(request_time * 1_000_000),
                 "L": f"{request_time:.6f}",
                 "p": f"<{os.getpid()}>",
